@@ -1,4 +1,4 @@
-/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
  *
  * This file is part of pdf2djvu.
  *
@@ -14,13 +14,12 @@
 
 #include "pdf-unicode.hh"
 
-#include <cstddef>
 #include <cassert>
 #include <climits>
+#include <cstddef>
+#include <cstdint>
 #include <sstream>
 
-#include <stdint.h>
-
 #include "autoconf.hh"
 
 #include <CharTypes.h>
