@@ -1,4 +1,4 @@
-/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2019 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -17,6 +17,7 @@
 #include <cassert>
 #include <cerrno>
 #include <cstddef>
+#include <cstdint>
 #include <cstdlib>
 #include <iomanip>
 #include <iostream>
@@ -34,8 +35,6 @@
 #include <omp.h>
 #endif
 
-#include <stdint.h>
-
 #include "config.hh"
 #include "debug.hh"
 #include "djvu-const.hh"
@@ -55,6 +54,10 @@
 #include "version.hh"
 #include "xmp.hh"
 
+#ifdef USE_HEAP_PROFILING
+#include <gperftools/heap-profiler.h>
+#endif
+
 static Config config;
 
 static inline DebugStream &debug(int n)
@@ -86,8 +89,8 @@ static int get_page_for_goto_link(pdf::link::GoTo *goto_link, pdf::Catalog *cata
     int page;
     if (dest->isPageRef())
     {
-      Ref pageref = dest->getPageRef();
-      page = catalog->findPage(pageref.num, pageref.gen);
+      pdf::Ref pageref = dest->getPageRef();
+      page = pdf::find_page(catalog, pageref);
     }
     else
       page = dest->getPageNum();
@@ -496,6 +499,12 @@ public:
       // L10N: OCG stands for “Optional Content Group” (see PDF Reference v1.7, §4.10.1)
       debug(1) << _("Warning: Unable to convert link with a set-OCG-state action") << std::endl;
       return;
+#if POPPLER_VERSION >= 6400
+    case actionHide:
+      debug(1) << _("Warning: Unable to convert link with a hide action") << std::endl;
+      return;
+#endif
+    case actionUnknown:
     default:
       debug(1) << _("Warning: Unknown link action") << std::endl;
       return;
@@ -535,7 +544,7 @@ public:
         bexpr = sexpr::cons(symbol_border, bexpr);
       }
       expr = sexpr::cons(bexpr, expr);
-    };
+    }
     {
       sexpr::Ref rexpr = sexpr::nil;
       rexpr = sexpr::cons(sexpr::integer(h), rexpr);
@@ -1216,7 +1225,7 @@ static int xmain(int argc, char * const argv[])
     std::cout << get_multiline_version();
     exit(0);
   }
-  catch (const Config::NeedHelp &ex)
+  catch (const Config::NeedHelp &)
   {
     config.usage();
     exit(0);
@@ -1338,7 +1347,7 @@ static int xmain(int argc, char * const argv[])
     djvm.reset(new IndirectDjVm(*output_file));
   }
   if (config.pages.size() == 0)
-    config.pages.push_back(std::make_pair(1, n_pages));
+    config.pages.push_back({1, n_pages});
   for (const std::pair<int, int> &page : config.pages)
   for (int n = page.first; n <= n_pages && n <= page.second; n++)
   {
@@ -1380,12 +1389,22 @@ static int xmain(int argc, char * const argv[])
   const char *doc_filename = nullptr;
 
   bool crop = !config.use_media_box;
+
+#ifdef USE_HEAP_PROFILING
+  HeapProfilerStart(config.output.c_str());
+#endif
   debug(0)++;
   #pragma omp parallel for private(out1, outm, outs, doc) firstprivate(doc_filename) reduction(+: djvu_pages_size) schedule(runtime)
   for (size_t i = 0; i < page_numbers.size(); i++)
   try
   {
     int n = page_numbers[i];
+#if USE_HEAP_PROFILING
+    {
+      std::string reason = string_printf("before page #%d", n);
+      HeapProfilerDump(reason.c_str());
+    }
+#endif
     pdf::PageInfo pi = document_map.get(n);
     const char * new_filename = pi.path;
     int m = pi.local_pageno;
@@ -1657,6 +1676,9 @@ static int xmain(int argc, char * const argv[])
     error_log << ex << std::endl;
     exit(1);
   }
+#ifdef USE_HEAP_PROFILING
+  HeapProfilerDump("after last page");
+#endif
   /* Only first PDF document metadata/outline is taken into account. */
   doc.reset(new pdf::Document(config.filenames[0]));
   if (config.extract_metadata)
@@ -1738,6 +1760,10 @@ static int xmain(int argc, char * const argv[])
   }
   if (config.output_stdout)
     copy_stream(*output_file, std::cout, true);
+#if USE_HEAP_PROFILING
+  HeapProfilerDump("before exit");
+  HeapProfilerStop();
+#endif
   return 0;
 }
 
